@@ -73,6 +73,9 @@ class Drawing:
     def drawPath(self, path):
         self._drawItem(self._canvas.drawPath, path.path)
 
+    def clipPath(self, path):
+        self._canvas.clipPath(path.path, doAntiAlias=True)
+
     def fill(self, *args):
         self._gstate.setFillColor(_colorArgs(args))
 
@@ -93,7 +96,7 @@ class Drawing:
     def lineJoin(self, lineJoin):
         self._gstate.setLineJoin(lineJoin)
 
-    def lineDash(self, firstValue, *values):
+    def lineDash(self, firstValue=None, *values):
         if firstValue is None:
             if values:
                 raise TypeError("lineDash() argument(s) should be None, or one or more numbers")
@@ -133,18 +136,9 @@ class Drawing:
             return
 
         glyphsInfo = self._gstate.textStyle.shape(txt)
-        builder = skia.TextBlobBuilder()
-        builder.allocRunPos(self._gstate.textStyle.skFont, glyphsInfo.gids, glyphsInfo.positions)
-        blob = builder.make()
+        blob = self._gstate.textStyle.makeTextBlob(glyphsInfo, align)
 
         x, y = position
-        textWidth = glyphsInfo.endPos[0]
-        if align is None:
-            align = "left" if not glyphsInfo.baseLevel else "right"
-        if align == "right":
-            x -= textWidth
-        elif align == "center":
-            x -= textWidth / 2
 
         self._canvas.save()
         try:
