@@ -234,6 +234,7 @@ class TextStyle(_ImmutableContainer):
     features = {}  # won't get mutated
     variations = {}  # won't get mutated
     language = None
+    font = None
 
     def __init__(self, **properties):
         super().__init__(**properties)
@@ -255,13 +256,16 @@ class TextStyle(_ImmutableContainer):
     def _getTypefaceAndTTFont(fontNameOrPath):
         cacheKey = fontNameOrPath
         if cacheKey not in _fontCache:
-            fontNameOrPath = os.fspath(fontNameOrPath)
-            if not os.path.exists(fontNameOrPath):
-                typeface = skia.Typeface(fontNameOrPath)
+            if fontNameOrPath is None:
+                typeface = skia.Typeface(None)
             else:
-                typeface = skia.Typeface.MakeFromFile(fontNameOrPath)
-                if typeface is None:
-                    raise DrawbotError(f"can't load font: {fontNameOrPath}")
+                fontNameOrPath = os.fspath(fontNameOrPath)
+                if not os.path.exists(fontNameOrPath):
+                    typeface = skia.Typeface(fontNameOrPath)
+                else:
+                    typeface = skia.Typeface.MakeFromFile(fontNameOrPath)
+                    if typeface is None:
+                        raise DrawbotError(f"can't load font: {fontNameOrPath}")
             ttFont = makeTTFontFromSkiaTypeface(typeface)
             _fontCache[cacheKey] = typeface, ttFont
         return _fontCache[cacheKey]
@@ -320,6 +324,23 @@ class TextStyle(_ImmutableContainer):
         glyphsInfo.baseLevel = baseLevel
         return glyphsInfo
 
+    def alignGlyphPositions(self, glyphsInfo, align):
+        textWidth = glyphsInfo.endPos[0]
+        if align is None:
+            align = "left" if not glyphsInfo.baseLevel else "right"
+        xOffset = 0
+        if align == "right":
+            xOffset = -textWidth
+        elif align == "center":
+            xOffset = -textWidth / 2
+        glyphsInfo.positions = [(x + xOffset, y) for x, y in glyphsInfo.positions]
+
+    def makeTextBlob(self, glyphsInfo, align):
+        self.alignGlyphPositions(glyphsInfo, align)
+        builder = skia.TextBlobBuilder()
+        builder.allocRunPos(self.skFont, glyphsInfo.gids, glyphsInfo.positions)
+        return builder.make()
+
 
 # Font cache dict
 # - keys: font name or path string
